@@ -1,12 +1,12 @@
 ibs <-
 function (x, df = NULL, knots = NULL, intercept = FALSE, Boundary.knots = range(x), 
-            from = 0, weight.fun = NULL, ...) {
+            from = 0, weight.fun = NULL, integrand.fun = NULL, ...) {
     if (!is.null(weight.fun) && !is.function(weight.fun))
         stop("'weight.fun' must be a function.\n")
     bs.x <- if (is.null(knots)) {
-        bs(x, df = df, intercept = intercept, Boundary.knots = Boundary.knots)
+        splines::bs(x, df = df, intercept = intercept, Boundary.knots = Boundary.knots)
     } else {
-        bs(x, knots = knots, intercept = intercept, Boundary.knots = Boundary.knots)
+        splines::bs(x, knots = knots, intercept = intercept, Boundary.knots = Boundary.knots)
     } 
     kn <- attr(bs.x, "knots")
     Bkn <- attr(bs.x, "Boundary.knots")
@@ -18,7 +18,11 @@ function (x, df = NULL, knots = NULL, intercept = FALSE, Boundary.knots = range(
     st <- outer(P2, sk) + P1
     out <- vector("list", 15L)
     for (i in seq_len(15)) {
-        out[[i]] <- wk[i] * bs(st[, i], knots = kn, Boundary.knots = Bkn, intercept = intercept)
+        basis <- splines::bs(st[, i], knots = kn, Boundary.knots = Bkn, 
+                             intercept = intercept)
+        if (!is.null(integrand.fun))
+            basis <- integrand.fun(basis)
+        out[[i]] <- wk[i] * basis
         if (!is.null(weight.fun)) {
             ww <- c(weight.fun(st[, i], x, ...))
             out[[i]] <- out[[i]] * ifelse(is.finite(ww), ww, 0)
