@@ -46,13 +46,13 @@ mvJointModelBayes <- function (mvglmerObject, survObject, timeVar,
         if (class(survObject) == 'survreg') {
             stop("Please refit the survival submodel using coxph().\n")
         }
-        if (is.null(survObject$model$cluster)) {
+        if (is.null(survObject$model$`(cluster)`)) {
             stop("you need to refit the Cox and include in the right hand side of the ",
                  "formula the 'cluster()' function using as its argument the subjects' ",
                  "id indicator. These ids need to be the same as the ones used to fit ",
                  "the mixed effects model.\n")
         }
-        idT <- survObject$model$cluster
+        idT <- survObject$model$`(cluster)`
         LongFormat <- length(idT) > length(unique(idT))
         TimeL <- TimeLl <- SurvInf[, "start"]
         fidT <- factor(idT, levels = unique(idT))
@@ -64,21 +64,21 @@ mvJointModelBayes <- function (mvglmerObject, survObject, timeVar,
         nT <- length(Time)
         eventLong <- SurvInf[, "status"]
         event  <- c(tapply(eventLong, fidT, tail, n = 1))
-        Terms <- drop.terms(Terms, attr(Terms,"specials")$cluster - 1,
-                            keep.response = TRUE)
+        #Terms <- drop.terms(Terms, attr(Terms,"specials")$cluster - 1,
+        #                    keep.response = TRUE)
     }
     if (typeSurvInf == "counting" && multiState) {
         if (class(survObject) == 'survreg') {
             stop("Please refit the survival submodel using coxph(). \n")
         }
-        if (is.null(survObject$model$cluster)) {
+        if (is.null(survObject$model$`(cluster)`)) {
             stop("you need to refit the Cox and include in the right hand side of the ", 
                  "formula the 'cluster()' function using as its argument the subjects' ", 
                  "id indicator. These ids need to be the same as the ones used in the ", 
                  "data_MultiState dataset. \n")
         }
         con$lng.in.kn <- con$lng.in.kn.multiState
-        idT <- survObject$model$cluster
+        idT <- survObject$model$`(cluster)`
         LongFormat <- length(idT) > length(unique(idT))
         TimeL <- TimeLl <- SurvInf[, "start"]
         fidT <- factor(idT, levels = unique(idT))
@@ -88,8 +88,8 @@ mvJointModelBayes <- function (mvglmerObject, survObject, timeVar,
         nT.long <- length(idT)
         event <- eventLong <- SurvInf[, "status"]
         nRisks <- length(unique(survObject$strata))
-        Terms <- drop.terms(Terms, attr(Terms, "specials")$cluster - 1, 
-                            keep.response = TRUE)
+        #Terms <- drop.terms(Terms, attr(Terms, "specials")$cluster - 1, 
+        #                    keep.response = TRUE)
         state.id <- gsub("^strata*\\((.*)\\).*", "\\1", 
                          colnames(dataS)[grep("^strata", colnames(dataS))])
         state.id2 <- colnames(dataS)[grep("^strata", colnames(dataS))]
@@ -544,11 +544,11 @@ mvJointModelBayes <- function (mvglmerObject, survObject, timeVar,
         which(x) - 1
     })
     if (typeSurvInf == "counting" && multiState) {
-        idT.list <- list(idT)
+        idT.list <- rep(list(idT), times = n_outcomes)
         Wlong <- designMatLong(XX, postMean_betas, ZZ, postMean_b, idT.list, outcome, 
                                indFixed, indRandom, U, trans_Funs)
         idTs <- rep(idT, each = K)
-        idTs.list <- list(idTs)
+        idTs.list <- rep(list(idTs), times = n_outcomes)
         Wlongs <- designMatLong(XXs, postMean_betas, ZZs, postMean_b, idTs.list, outcome, 
                                 indFixed, indRandom, Us, trans_Funs)
         idT_rsum <- c(idT[-length(idT)] != idT[-1L], TRUE)
